==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/item/equipment/tool/elementium/ElementiumShovelItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.equipment.tool.elementium;

import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2346;
import net.minecraft.class_2382;
import net.minecraft.class_2680;
import vazkii.botania.api.BotaniaAPI;
import vazkii.botania.common.annotations.SoftImplement;
import vazkii.botania.common.item.equipment.tool.ToolCommons;
import vazkii.botania.common.item.equipment.tool.manasteel.ManasteelShovelItem;

public class ElementiumShovelItem extends ManasteelShovelItem {

	public ElementiumShovelItem(class_1793 props) {
		super(BotaniaAPI.instance().getElementiumItemTier(), props);
	}

	@SoftImplement("IForgeItem")
	public boolean onBlockStartBreak(class_1799 stack, class_2338 pos, class_1657 player) {
		class_1937 world = player.field_6002;
		class_2680 blockState = world.method_8320(pos);
		if (this.method_7865(stack, blockState) <= 1.0F) {
			return false;
		}

		class_2248 blk = blockState.method_26204();
		if (blk instanceof class_2346) {
			ToolCommons.removeBlocksInIteration(player, stack, world, pos, new class_2382(0, -12, 0),
					new class_2382(1, 12, 1),
					state -> state.method_27852(blk));
		}

		return false;
	}

}

==> Botania-1.20.1-449-FABRIC-20250801.175524-45-sources.jar: vazkii/botania/common/item/equipment/tool/elementium/ElementiumShovelItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.equipment.tool.elementium;

import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2346;
import net.minecraft.class_2382;
import net.minecraft.class_2680;
import vazkii.botania.api.BotaniaAPI;
import vazkii.botania.common.annotations.SoftImplement;
import vazkii.botania.common.item.equipment.tool.ToolCommons;
import vazkii.botania.common.item.equipment.tool.manasteel.ManasteelShovelItem;

public class ElementiumShovelItem extends ManasteelShovelItem {

	public ElementiumShovelItem(class_1793 props) {
		super(BotaniaAPI.instance().getElementiumItemTier(), props);
	}

	@SoftImplement("IForgeItem")
	public boolean onBlockStartBreak(class_1799 stack, class_2338 pos, class_1657 player) {
		class_1937 world = player.method_37908();
		class_2680 blockState = world.method_8320(pos);
		if (this.method_7865(stack, blockState) <= 1.0F) {
			return false;
		}

		class_2248 blk = blockState.method_26204();
		if (blk instanceof class_2346) {
			ToolCommons.removeBlocksInIteration(player, stack, world, pos, new class_2382(0, -12, 0),
					new class_2382(1, 12, 1),
					state -> state.method_27852(blk));
		}

		return false;
	}

}
